commands/impl/commads_export library

Classes

CreateControllerCommand
This command is a controller with the template:
CreatePageCommand
The command create a Binding and Controller page and view
CreateProjectCommand
CreateProviderCommand
CreateScreenCommand
CreateServiceCommand
This command creates a service class with the template:
CreateViewCommand
GenerateLocalesCommand
GenerateModelCommand
HelpCommand
InitCommand
InstallCommand
RemoveCommand
SortCommand
UpdateCommand
VersionCommand

Functions

createView(String name, {String withArgument = '', String onCommand = ''}) Future<void>