ValueNode class

Inheritance

Constructors

ValueNode(String value, String? raw, {String type = 'Identifier', Location? loc})

Properties

hashCode → int
The hash code for this object.
no setteroverride
loc → Location?
finalinherited
raw → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
finalinherited
value → String
final

Methods

copyWith({String? value, String? raw, String? type, Location? loc}) → ValueNode
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override